==> mobiusft-2.15.tar.xz: mobiusft-2.15/src/libmobius_core/os/win/hash_ie_entropy.cpp <==
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// Mobius Forensic Toolkit
// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024,2025 Eduardo Aguiar
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
// Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
#include <mobius/core/os/win/hash_ie_entropy.hpp>
#include <mobius/core/charset.hpp>
#include <mobius/core/crypt/hash.hpp>
#include <numeric>

namespace mobius::core::os::win
{
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// @brief Generate IE entropy hash from URL
// @param url URL
// @return IE entropy hash
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
mobius::core::bytearray
hash_ie_entropy (const std::string& url)
{
  mobius::core::crypt::hash h ("sha1");
  h.update (mobius::core::conv_charset (url + '\0', "UTF-8", "UTF-16LE"));
  auto digest = h.get_digest ();

  mobius::core::bytearray sum = {std::accumulate (digest.begin (), digest.end (), std::uint8_t (0))};
  return digest + sum;
}

} // namespace mobius::core::os::win

==> mobiusft-2.16.tar.xz: mobiusft-2.16/src/libmobius_core/os/win/hash_ie_entropy.cpp <==
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// Mobius Forensic Toolkit
// Copyright (C)
// 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024,2025
// Eduardo Aguiar
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
// Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
#include <mobius/core/charset.hpp>
#include <mobius/core/crypt/hash.hpp>
#include <mobius/core/os/win/hash_ie_entropy.hpp>
#include <numeric>

namespace mobius::core::os::win
{
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// @brief Generate IE entropy hash from URL
// @param url URL
// @return IE entropy hash
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
mobius::core::bytearray
hash_ie_entropy (const std::string &url)
{
    mobius::core::crypt::hash h ("sha1");
    h.update (mobius::core::conv_charset (url + '\0', "UTF-8", "UTF-16LE"));
    auto digest = h.get_digest ();

    mobius::core::bytearray sum = {
        std::accumulate (digest.begin (), digest.end (), std::uint8_t (0))};
    return digest + sum;
}

} // namespace mobius::core::os::win
